@@ -175,7 +175,12 @@ fn node_to_range<D: Doc>(node: &Node<D>) -> TSRange {
   let end = node.end_pos();
   let ep = end.byte_point();
   let ep = tree_sitter::Point::new(ep.0, ep.1);
-  TSRange::new(r.start as u32, r.end as u32, &sp, &ep)
+  TSRange {
+    start_byte: r.start,
+    end_byte: r.end,
+    start_point: sp,
+    end_point: ep,
+  }
 }
 
 #[cfg(test)]
